"""Shared types for messaging."""

TTo = str
TFrom = str
TNotifyUrl = str
TMessageId = str
TBody = str
TSentTimestamp = str
